linux-kernel.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
* [PATCH 5.10 0/2] 5.10.1-rc1 review
@ 2020-12-14 17:06 Greg Kroah-Hartman
  2020-12-14 17:06 ` [PATCH 5.10 1/2] Revert "md: change mddev chunk_sectors from int to unsigned" Greg Kroah-Hartman
                   ` (5 more replies)
  0 siblings, 6 replies; 11+ messages in thread
From: Greg Kroah-Hartman @ 2020-12-14 17:06 UTC (permalink / raw)
  To: linux-kernel
  Cc: Greg Kroah-Hartman, torvalds, akpm, linux, shuah, patches,
	lkft-triage, pavel, stable

This is the start of the stable review cycle for the 5.10.1 release.
There are 2 patches in this series, all will be posted as a response
to this one.  If anyone has any issues with these being applied, please
let me know.

Responses should be made by Monday, 14 Dec 2020 18:04:42 +0000.
Anything received after that time might be too late.

The whole patch series can be found in one patch at:
	https://www.kernel.org/pub/linux/kernel/v5.x/stable-review/patch-5.10.1-rc1.gz
or in the git tree and branch at:
	git://git.kernel.org/pub/scm/linux/kernel/git/stable/linux-stable-rc.git linux-5.10.y
and the diffstat can be found below.

thanks,

greg k-h

-------------
Pseudo-Shortlog of commits:

Greg Kroah-Hartman <gregkh@linuxfoundation.org>
    Linux 5.10.1-rc1

Greg Kroah-Hartman <gregkh@linuxfoundation.org>
    Revert "dm raid: fix discard limits for raid1 and raid10"

Greg Kroah-Hartman <gregkh@linuxfoundation.org>
    Revert "md: change mddev 'chunk_sectors' from int to unsigned"


-------------

Diffstat:

 Makefile             |  4 ++--
 drivers/md/dm-raid.c | 12 +++++-------
 drivers/md/md.h      |  4 ++--
 3 files changed, 9 insertions(+), 11 deletions(-)



^ permalink raw reply	[flat|nested] 11+ messages in thread

* [PATCH 5.10 1/2] Revert "md: change mddev chunk_sectors from int to unsigned"
  2020-12-14 17:06 [PATCH 5.10 0/2] 5.10.1-rc1 review Greg Kroah-Hartman
@ 2020-12-14 17:06 ` Greg Kroah-Hartman
  2020-12-14 17:06 ` [PATCH 5.10 2/2] Revert "dm raid: fix discard limits for raid1 and raid10" Greg Kroah-Hartman
                   ` (4 subsequent siblings)
  5 siblings, 0 replies; 11+ messages in thread
From: Greg Kroah-Hartman @ 2020-12-14 17:06 UTC (permalink / raw)
  To: linux-kernel
  Cc: Greg Kroah-Hartman, stable, Dave Jones, Mike Snitzer, Song Liu,
	Jens Axboe

From: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

This reverts commit 6ffeb1c3f8226244c08105bcdbeecc04bad6b89a.

It causes problems :(

Reported-by: Dave Jones <davej@codemonkey.org.uk>
Reported-by: Mike Snitzer <snitzer@redhat.com>
Cc: Song Liu <songliubraving@fb.com>
Cc: Jens Axboe <axboe@kernel.dk>
Cc: Linus Torvalds <torvalds@linux-foundation.org
Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
---
 drivers/md/md.h |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

--- a/drivers/md/md.h
+++ b/drivers/md/md.h
@@ -311,7 +311,7 @@ struct mddev {
 	int				external;	/* metadata is
 							 * managed externally */
 	char				metadata_type[17]; /* externally set*/
-	unsigned int			chunk_sectors;
+	int				chunk_sectors;
 	time64_t			ctime, utime;
 	int				level, layout;
 	char				clevel[16];
@@ -339,7 +339,7 @@ struct mddev {
 	 */
 	sector_t			reshape_position;
 	int				delta_disks, new_level, new_layout;
-	unsigned int			new_chunk_sectors;
+	int				new_chunk_sectors;
 	int				reshape_backwards;
 
 	struct md_thread		*thread;	/* management thread */



^ permalink raw reply	[flat|nested] 11+ messages in thread

* [PATCH 5.10 2/2] Revert "dm raid: fix discard limits for raid1 and raid10"
  2020-12-14 17:06 [PATCH 5.10 0/2] 5.10.1-rc1 review Greg Kroah-Hartman
  2020-12-14 17:06 ` [PATCH 5.10 1/2] Revert "md: change mddev chunk_sectors from int to unsigned" Greg Kroah-Hartman
@ 2020-12-14 17:06 ` Greg Kroah-Hartman
  2020-12-14 22:20 ` [PATCH 5.10 0/2] 5.10.1-rc1 review Shuah Khan
                   ` (3 subsequent siblings)
  5 siblings, 0 replies; 11+ messages in thread
From: Greg Kroah-Hartman @ 2020-12-14 17:06 UTC (permalink / raw)
  To: linux-kernel
  Cc: Greg Kroah-Hartman, stable, Dave Jones, Mike Snitzer,
	Zdenek Kabelac, Mikulas Patocka

From: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

This reverts commit e0910c8e4f87bb9f767e61a778b0d9271c4dc512.

It causes problems :(

Reported-by: Dave Jones <davej@codemonkey.org.uk>
Reported-by: Mike Snitzer <snitzer@redhat.com>
Cc: Zdenek Kabelac <zkabelac@redhat.com>
Cc: Mikulas Patocka <mpatocka@redhat.com>
Cc: Linus Torvalds <torvalds@linux-foundation.org
Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
---
 drivers/md/dm-raid.c |   12 +++++-------
 1 file changed, 5 insertions(+), 7 deletions(-)

--- a/drivers/md/dm-raid.c
+++ b/drivers/md/dm-raid.c
@@ -3730,14 +3730,12 @@ static void raid_io_hints(struct dm_targ
 	blk_limits_io_opt(limits, chunk_size_bytes * mddev_data_stripes(rs));
 
 	/*
 	 * RAID10 personality requires bio splitting,
 	 * RAID0/1/4/5/6 don't and process large discard bios properly.
 	 */
-	if (rs_is_raid10(rs)) {
-		limits->discard_granularity = max(chunk_size_bytes,
-						  limits->discard_granularity);
-		limits->max_discard_sectors = min_not_zero(rs->md.chunk_sectors,
-							   limits->max_discard_sectors);
+	if (rs_is_raid1(rs) || rs_is_raid10(rs)) {
+		limits->discard_granularity = chunk_size_bytes;
+		limits->max_discard_sectors = rs->md.chunk_sectors;
 	}
 }
 



^ permalink raw reply	[flat|nested] 11+ messages in thread

* Re: [PATCH 5.10 0/2] 5.10.1-rc1 review
  2020-12-14 17:06 [PATCH 5.10 0/2] 5.10.1-rc1 review Greg Kroah-Hartman
  2020-12-14 17:06 ` [PATCH 5.10 1/2] Revert "md: change mddev chunk_sectors from int to unsigned" Greg Kroah-Hartman
  2020-12-14 17:06 ` [PATCH 5.10 2/2] Revert "dm raid: fix discard limits for raid1 and raid10" Greg Kroah-Hartman
@ 2020-12-14 22:20 ` Shuah Khan
  2020-12-15  9:24   ` Greg Kroah-Hartman
  2020-12-15  9:20 ` Jon Hunter
                   ` (2 subsequent siblings)
  5 siblings, 1 reply; 11+ messages in thread
From: Shuah Khan @ 2020-12-14 22:20 UTC (permalink / raw)
  To: Greg Kroah-Hartman, linux-kernel
  Cc: torvalds, akpm, linux, shuah, patches, lkft-triage, pavel,
	stable, Shuah Khan

On 12/14/20 10:06 AM, Greg Kroah-Hartman wrote:
> This is the start of the stable review cycle for the 5.10.1 release.
> There are 2 patches in this series, all will be posted as a response
> to this one.  If anyone has any issues with these being applied, please
> let me know.
> 
> Responses should be made by Monday, 14 Dec 2020 18:04:42 +0000.
> Anything received after that time might be too late.
> 
> The whole patch series can be found in one patch at:
> 	https://www.kernel.org/pub/linux/kernel/v5.x/stable-review/patch-5.10.1-rc1.gz
> or in the git tree and branch at:
> 	git://git.kernel.org/pub/scm/linux/kernel/git/stable/linux-stable-rc.git linux-5.10.y
> and the diffstat can be found below.
> 
> thanks,
> 
> greg k-h
> 

Compiled and booted on my test system. No dmesg regressions.

Tested-by: Shuah Khan <skhan@linuxfoundation.org>

thanks,
-- Shuah

^ permalink raw reply	[flat|nested] 11+ messages in thread

* Re: [PATCH 5.10 0/2] 5.10.1-rc1 review
  2020-12-14 17:06 [PATCH 5.10 0/2] 5.10.1-rc1 review Greg Kroah-Hartman
                   ` (2 preceding siblings ...)
  2020-12-14 22:20 ` [PATCH 5.10 0/2] 5.10.1-rc1 review Shuah Khan
@ 2020-12-15  9:20 ` Jon Hunter
  2020-12-15  9:29   ` Greg Kroah-Hartman
  2020-12-15 10:20 ` Naresh Kamboju
  2020-12-15 20:32 ` Guenter Roeck
@@ -3730,14 +3730,12 @@ static void raid_io_hints(struct dm_targ
 
 	/*
-	 * RAID10 personality requires bio splitting,
-	 * RAID0/1/4/5/6 don't and process large discard bios properly.
+	 * RAID1 and RAID10 personalities require bio splitting,
+	 * RAID0/4/5/6 don't and process large discard bios properly.
 	 */
  5 siblings, 1 reply; 11+ messages in thread
From: Jon Hunter @ 2020-12-15  9:20 UTC (permalink / raw)
  To: Greg Kroah-Hartman, linux-kernel
  Cc: torvalds, akpm, linux, shuah, patches, lkft-triage, pavel, stable

Hi Greg,

On 14/12/2020 17:06, Greg Kroah-Hartman wrote:
> This is the start of the stable review cycle for the 5.10.1 release.
> There are 2 patches in this series, all will be posted as a response
> to this one.  If anyone has any issues with these being applied, please
> let me know.
> 
> Responses should be made by Monday, 14 Dec 2020 18:04:42 +0000.
> Anything received after that time might be too late.
> 
> The whole patch series can be found in one patch at:
> 	https://www.kernel.org/pub/linux/kernel/v5.x/stable-review/patch-5.10.1-rc1.gz
> or in the git tree and branch at:
> 	git://git.kernel.org/pub/scm/linux/kernel/git/stable/linux-stable-rc.git linux-5.10.y
> and the diffstat can be found below.
> 
> thanks,
> 
> greg k-h


Test results for stable-v5.10:
    15 builds:	15 pass, 0 fail
    26 boots:	26 pass, 0 fail
    64 tests:	63 pass, 1 fail

Linux version:	5.10.1-g841fca5a32cc
Boards tested:	tegra124-jetson-tk1, tegra186-p2771-0000,
                tegra194-p2972-0000, tegra20-ventana,
                tegra210-p2371-2180, tegra210-p3450-0000,
                tegra30-cardhu-a04

Test failures:	tegra194-p2972-0000: boot.py


Some changes in v5.10 exposed a minor issue in the kernel that can cause
a blank line warning to be seen. The above test is failing due to this
blank warning. Thierry has posted a fix for this [0] and should be
merged for v5.11. It was not tagged for stable, but if you OK to pull
this in once in the mainline I can send a request. Otherwise all looks
good, so ...

Tested-by: Jon Hunter <jonathanh@nvidia.com>

Cheers
Jon

[0] https://lore.kernel.org/patchwork/patch/1336079/

-- 
nvpublic

^ permalink raw reply	[flat|nested] 11+ messages in thread

* Re: [PATCH 5.10 0/2] 5.10.1-rc1 review
  2020-12-14 22:20 ` [PATCH 5.10 0/2] 5.10.1-rc1 review Shuah Khan
@ 2020-12-15  9:24   ` Greg Kroah-Hartman
  0 siblings, 0 replies; 11+ messages in thread
From: Greg Kroah-Hartman @ 2020-12-15  9:24 UTC (permalink / raw)
  To: Shuah Khan
  Cc: linux-kernel, torvalds, akpm, linux, shuah, patches, lkft-triage,
	pavel, stable

On Mon, Dec 14, 2020 at 03:20:38PM -0700, Shuah Khan wrote:
> On 12/14/20 10:06 AM, Greg Kroah-Hartman wrote:
> > This is the start of the stable review cycle for the 5.10.1 release.
> > There are 2 patches in this series, all will be posted as a response
> > to this one.  If anyone has any issues with these being applied, please
> > let me know.
> > 
> > Responses should be made by Monday, 14 Dec 2020 18:04:42 +0000.
> > Anything received after that time might be too late.
> > 
> > The whole patch series can be found in one patch at:
> > 	https://www.kernel.org/pub/linux/kernel/v5.x/stable-review/patch-5.10.1-rc1.gz
> > or in the git tree and branch at:
> > 	git://git.kernel.org/pub/scm/linux/kernel/git/stable/linux-stable-rc.git linux-5.10.y
> > and the diffstat can be found below.
> > 
> > thanks,
> > 
> > greg k-h
> > 
> 
> Compiled and booted on my test system. No dmesg regressions.
> 
> Tested-by: Shuah Khan <skhan@linuxfoundation.org>

Thanks for testing this one and letting me know!

greg k-h

^ permalink raw reply	[flat|nested] 11+ messages in thread

* Re: [PATCH 5.10 0/2] 5.10.1-rc1 review
  2020-12-15  9:20 ` Jon Hunter
@ 2020-12-15  9:29   ` Greg Kroah-Hartman
  0 siblings, 0 replies; 11+ messages in thread
From: Greg Kroah-Hartman @ 2020-12-15  9:29 UTC (permalink / raw)
  To: Jon Hunter
  Cc: linux-kernel, torvalds, akpm, linux, shuah, patches, lkft-triage,
	pavel, stable

On Tue, Dec 15, 2020 at 09:20:26AM +0000, Jon Hunter wrote:
> Hi Greg,
> 
> On 14/12/2020 17:06, Greg Kroah-Hartman wrote:
> > This is the start of the stable review cycle for the 5.10.1 release.
> > There are 2 patches in this series, all will be posted as a response
> > to this one.  If anyone has any issues with these being applied, please
> > let me know.
> > 
> > Responses should be made by Monday, 14 Dec 2020 18:04:42 +0000.
> > Anything received after that time might be too late.
> > 
> > The whole patch series can be found in one patch at:
> > 	https://www.kernel.org/pub/linux/kernel/v5.x/stable-review/patch-5.10.1-rc1.gz
> > or in the git tree and branch at:
> > 	git://git.kernel.org/pub/scm/linux/kernel/git/stable/linux-stable-rc.git linux-5.10.y
> > and the diffstat can be found below.
> > 
> > thanks,
> > 
> > greg k-h
> 
> 
> Test results for stable-v5.10:
>     15 builds:	15 pass, 0 fail
>     26 boots:	26 pass, 0 fail
>     64 tests:	63 pass, 1 fail
> 
> Linux version:	5.10.1-g841fca5a32cc
> Boards tested:	tegra124-jetson-tk1, tegra186-p2771-0000,
>                 tegra194-p2972-0000, tegra20-ventana,
>                 tegra210-p2371-2180, tegra210-p3450-0000,
>                 tegra30-cardhu-a04
> 
> Test failures:	tegra194-p2972-0000: boot.py
> 
> 
> Some changes in v5.10 exposed a minor issue in the kernel that can cause
> a blank line warning to be seen. The above test is failing due to this
> blank warning. Thierry has posted a fix for this [0] and should be
> merged for v5.11. It was not tagged for stable, but if you OK to pull
> this in once in the mainline I can send a request. Otherwise all looks
> good, so ...
> 
> Tested-by: Jon Hunter <jonathanh@nvidia.com>

Thanks for testing this, and yes, I'll be glad to take this once it hits
Linus's tree, just let me know the git commit id of it there.

thanks,

greg k-h

^ permalink raw reply	[flat|nested] 11+ messages in thread

* Re: [PATCH 5.10 0/2] 5.10.1-rc1 review
  2020-12-14 17:06 [PATCH 5.10 0/2] 5.10.1-rc1 review Greg Kroah-Hartman
                   ` (3 preceding siblings ...)
  2020-12-15  9:20 ` Jon Hunter
@ 2020-12-15 10:20 ` Naresh Kamboju
  2020-12-15 10:27   ` Greg Kroah-Hartman
  2020-12-15 20:32 ` Guenter Roeck
  5 siblings, 1 reply; 11+ messages in thread
From: Naresh Kamboju @ 2020-12-15 10:20 UTC (permalink / raw)
  To: Greg Kroah-Hartman
  Cc: open list, Shuah Khan, patches, lkft-triage, linux-stable, pavel,
	Andrew Morton, Linus Torvalds, Guenter Roeck

On Mon, 14 Dec 2020 at 22:35, Greg Kroah-Hartman
<gregkh@linuxfoundation.org> wrote:
>
> This is the start of the stable review cycle for the 5.10.1 release.
> There are 2 patches in this series, all will be posted as a response
> to this one.  If anyone has any issues with these being applied, please
> let me know.
>
> Responses should be made by Monday, 14 Dec 2020 18:04:42 +0000.
> Anything received after that time might be too late.
>
> The whole patch series can be found in one patch at:
>         https://www.kernel.org/pub/linux/kernel/v5.x/stable-review/patch-5.10.1-rc1.gz
> or in the git tree and branch at:
>         git://git.kernel.org/pub/scm/linux/kernel/git/stable/linux-stable-rc.git linux-5.10.y
> and the diffstat can be found below.
>
> thanks,
>
> greg k-h

Results from Linaro’s test farm.
No regressions on arm64, arm, x86_64, and i386.

Tested-by: Linux Kernel Functional Testing <lkft@linaro.org>

Summary
------------------------------------------------------------------------

kernel: 5.10.1
git repo: https://git.kernel.org/pub/scm/linux/kernel/git/stable/linux-stable-rc.git
git branch: linux-5.10.y
git commit: 841fca5a32cccd7d0123c0271f4350161ada5507
git describe: v5.10.1
Test details: https://qa-reports.linaro.org/lkft/linux-stable-rc-linux-5.10.y/build/v5.10.1


No regressions (compared to build v5.10.1)

No fixes (compared to build v5.10.1)

Ran 56654 total tests in the following environments and test suites.

Environments
--------------
- arc
- arm
- arm64
- dragonboard-410c
- hi6220-hikey
- i386
- juno-r2
- juno-r2-compat
- juno-r2-kasan
- mips
- nxp-ls2088
- parisc
- powerpc
- qemu-arm-clang
- qemu-arm64-clang
- qemu-arm64-kasan
- qemu-i386-clang
- qemu-x86_64-clang
- qemu-x86_64-kasan
- qemu-x86_64-kcsan
- qemu_arm
- qemu_arm64
- qemu_arm64-compat
- qemu_i386
- qemu_x86_64
- qemu_x86_64-compat
- riscv
- s390
- sh
- sparc
- x15
- x86
- x86-kasan

Test Suites
-----------
* build
* linux-log-parser
* install-android-platform-tools-r2600
* kselftest
* ltp-commands-tests
* ltp-cve-tests
* ltp-fcntl-locktests-tests
* ltp-filecaps-tests
* ltp-fs_bind-tests
* ltp-fs_perms_simple-tests
* ltp-fsx-tests
* ltp-hugetlb-tests
* ltp-math-tests
* ltp-mm-tests
* ltp-nptl-tests
* ltp-pty-tests
* ltp-sched-tests
* ltp-securebits-tests
* ltp-tracing-tests
* v4l2-compliance
* kvm-unit-tests
* libhugetlbfs
* ltp-cap_bounds-tests
* ltp-cpuhotplug-tests
* ltp-crypto-tests
* ltp-fs-tests
* ltp-ipc-tests
* ltp-syscalls-tests
* network-basic-tests
* ltp-containers-tests
* ltp-controllers-tests
* ltp-dio-tests
* ltp-io-tests
* ltp-open-posix-tests
* perf
* fwts
* kunit
* rcutorture
* kselftest-vsyscall-mode-native
* kselftest-vsyscall-mode-none

-- 
Linaro LKFT
https://lkft.linaro.org

^ permalink raw reply	[flat|nested] 11+ messages in thread

* Re: [PATCH 5.10 0/2] 5.10.1-rc1 review
  2020-12-15 10:20 ` Naresh Kamboju
@ 2020-12-15 10:27   ` Greg Kroah-Hartman
  0 siblings, 0 replies; 11+ messages in thread
From: Greg Kroah-Hartman @ 2020-12-15 10:27 UTC (permalink / raw)
  To: Naresh Kamboju
  Cc: open list, Shuah Khan, patches, lkft-triage, linux-stable, pavel,
	Andrew Morton, Linus Torvalds, Guenter Roeck

On Tue, Dec 15, 2020 at 03:50:57PM +0530, Naresh Kamboju wrote:
> On Mon, 14 Dec 2020 at 22:35, Greg Kroah-Hartman
> <gregkh@linuxfoundation.org> wrote:
> >
> > This is the start of the stable review cycle for the 5.10.1 release.
> > There are 2 patches in this series, all will be posted as a response
> > to this one.  If anyone has any issues with these being applied, please
> > let me know.
> >
> > Responses should be made by Monday, 14 Dec 2020 18:04:42 +0000.
> > Anything received after that time might be too late.
> >
> > The whole patch series can be found in one patch at:
> >         https://www.kernel.org/pub/linux/kernel/v5.x/stable-review/patch-5.10.1-rc1.gz
> > or in the git tree and branch at:
> >         git://git.kernel.org/pub/scm/linux/kernel/git/stable/linux-stable-rc.git linux-5.10.y
> > and the diffstat can be found below.
> >
> > thanks,
> >
> > greg k-h
> 
> Results from Linaro’s test farm.
> No regressions on arm64, arm, x86_64, and i386.
> 
> Tested-by: Linux Kernel Functional Testing <lkft@linaro.org>

Thanks for testing this one!

greg k-h

^ permalink raw reply	[flat|nested] 11+ messages in thread

* Re: [PATCH 5.10 0/2] 5.10.1-rc1 review
  2020-12-14 17:06 [PATCH 5.10 0/2] 5.10.1-rc1 review Greg Kroah-Hartman
                   ` (4 preceding siblings ...)
  2020-12-15 10:20 ` Naresh Kamboju
@ 2020-12-15 20:32 ` Guenter Roeck
  2020-12-16  9:47   ` Greg Kroah-Hartman
  5 siblings, 1 reply; 11+ messages in thread
From: Guenter Roeck @ 2020-12-15 20:32 UTC (permalink / raw)
  To: Greg Kroah-Hartman
  Cc: linux-kernel, torvalds, akpm, shuah, patches, lkft-triage, pavel, stable

On Mon, Dec 14, 2020 at 06:06:09PM +0100, Greg Kroah-Hartman wrote:
> This is the start of the stable review cycle for the 5.10.1 release.
> There are 2 patches in this series, all will be posted as a response
> to this one.  If anyone has any issues with these being applied, please
> let me know.
> 
> Responses should be made by Monday, 14 Dec 2020 18:04:42 +0000.
> Anything received after that time might be too late.
> 

Build results:
	total: 154 pass: 154 fail: 0
Qemu test results:
	total: 427 pass: 427 fail: 0

Tested-by: Guenter Roeck <linux@roeck-us.net>

Guenter

^ permalink raw reply	[flat|nested] 11+ messages in thread

* Re: [PATCH 5.10 0/2] 5.10.1-rc1 review
  2020-12-15 20:32 ` Guenter Roeck
@ 2020-12-16  9:47   ` Greg Kroah-Hartman
  0 siblings, 0 replies; 11+ messages in thread
From: Greg Kroah-Hartman @ 2020-12-16  9:47 UTC (permalink / raw)
  To: Guenter Roeck
  Cc: linux-kernel, torvalds, akpm, shuah, patches, lkft-triage, pavel, stable

On Tue, Dec 15, 2020 at 12:32:26PM -0800, Guenter Roeck wrote:
> On Mon, Dec 14, 2020 at 06:06:09PM +0100, Greg Kroah-Hartman wrote:
> > This is the start of the stable review cycle for the 5.10.1 release.
> > There are 2 patches in this series, all will be posted as a response
> > to this one.  If anyone has any issues with these being applied, please
> > let me know.
> > 
> > Responses should be made by Monday, 14 Dec 2020 18:04:42 +0000.
> > Anything received after that time might be too late.
> > 
> 
> Build results:
> 	total: 154 pass: 154 fail: 0
> Qemu test results:
> 	total: 427 pass: 427 fail: 0
> 
> Tested-by: Guenter Roeck <linux@roeck-us.net>

Thanks for testing!
greg k-h

^ permalink raw reply	[flat|nested] 11+ messages in thread

end of thread, other threads:[~2020-12-16  9:47 UTC | newest]

Thread overview: 11+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2020-12-14 17:06 [PATCH 5.10 0/2] 5.10.1-rc1 review Greg Kroah-Hartman
2020-12-14 17:06 ` [PATCH 5.10 1/2] Revert "md: change mddev chunk_sectors from int to unsigned" Greg Kroah-Hartman
2020-12-14 17:06 ` [PATCH 5.10 2/2] Revert "dm raid: fix discard limits for raid1 and raid10" Greg Kroah-Hartman
2020-12-14 22:20 ` [PATCH 5.10 0/2] 5.10.1-rc1 review Shuah Khan
2020-12-15  9:24   ` Greg Kroah-Hartman
2020-12-15  9:20 ` Jon Hunter
2020-12-15  9:29   ` Greg Kroah-Hartman
2020-12-15 10:20 ` Naresh Kamboju
2020-12-15 10:27   ` Greg Kroah-Hartman
2020-12-15 20:32 ` Guenter Roeck
2020-12-16  9:47   ` Greg Kroah-Hartman

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).